-- RandomSay

-- command to say one of a bunch of things

-- use:
-- /rem chance thing1/thing2/thing3/...
-- /rs chance thing1/thing2/thing3/...
--
-- Randomly picks one of the slash-separated strings and 
-- says or emotes it.  If chance is supplied, then generates
-- a random number from 1 to 100, and, if it is less than or
-- equal to chance, picks one of the strings and says or 
-- emotes it.

--

-- Example:
--  /rs 20 Lok'tar ogar!/Death to the foes of the Horde!
--    - has a 20% chance to say something.  If it does, will
--      say one of the two possiblities given.

-- create namespace for our... well, one function. At least
-- it makes name collisions unlikely.

function GetRandomArgument(...)
  return (select(random(select("#", ...)), ...));
end

RandomSay = {}

function RandomSay.parse (args)
    -- for use by other addons that might want use RandomSay as a library
    -- returns one of the given strings, or, if the chance failed, 
    -- a nil value
    -- 
    -- see "RandomChat" below for example of use

    first, last = string.find(args, "^(%d+%.?%d)%s")
    if first then 
        chance = tonumber(string.sub(args, first, last))
        args = string.sub(args,last+1)
        if ( math.random(100) > chance) then
             return nil
        end
    end
    return GetRandomArgument(strsplit("/",args))
end

local function RandomChat (chattype, args)
    local arg = RandomSay.parse(args)
    if arg then SendChatMessage(arg, chattype) end
end

SLASH_RANDOMSAY1 = "/rsay"
SLASH_RANDOMSAY2 = "/rs"
SLASH_RANDOMEMOTE1 = "/remote"
SLASH_RANDOMEMOTE2 = "/rem"
SLASH_RANDOMYELL1 = "/ryell"
SLASH_RANDOMYELL2 = "/ry"
SLASH_RANDOMGUILD1 = "/rg"
SLASH_RANDOMGUILD2 = "/rguild"

SlashCmdList["RANDOMSAY"] = function (args)
    RandomChat("SAY", args)
end

SlashCmdList["RANDOMEMOTE"] = function (args)
    RandomChat("EMOTE", args)
end

SlashCmdList["RANDOMYELL"] = function (args)
    RandomChat("YELL", args)
end

SlashCmdList["RANDOMGUILD"] = function (args)
    RandomChat("GUILD", args)
end

